IconFontConfig class
Constructors
Properties
-
assetPaths
→ List<
String> -
final
- familyName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconPrefix → String
-
Prefix prepended to every generated identifier. Defaults to
icn.final - namingStrategy → NamingStrategy
-
Strategy used to convert ligature names to Dart identifiers.
Defaults to
PascalNamingStrategy.final - outputFamily → String?
-
When set, overrides the
fontFamilyvalue written into every generatedIconDataconstant. Defaults to familyName when null.final - outputPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited